@@ -7,14 +7,13 @@ use std::io::{self, IoSlice, Read, Write};
 use std::mem::size_of;
 use std::sync::Arc;
 use std::time::Duration;
-
 use vm_memory::ByteValued;
 
 use super::{
     MetricsHook, Server, ServerUtil, ServerVersion, SrvContext, ZcReader, ZcWriter,
     BUFFER_HEADER_SIZE, DIRENT_PADDING, MAX_BUFFER_SIZE, MAX_REQ_PAGES, MIN_READ_BUFFER,
 };
-use crate::abi::linux_abi::*;
+use crate::abi::fuse_abi::*;
 #[cfg(feature = "virtiofs")]
 use crate::abi::virtio_fs::{RemovemappingIn, RemovemappingOne, SetupmappingIn};
 use crate::api::filesystem::{
@@ -106,7 +105,7 @@ impl<F: FileSystem + Sync, D: AsyncDrive> Server<F, D> {
                     Ok(0)
                 }
                 x if x == Opcode::Destroy as u32 => {
-                    self.destroy();
+                    self.destroy(ctx);
                     Ok(0)
                 }
                 _ => ctx.reply_error(io::Error::from_raw_os_error(libc::ENOSYS)),
@@ -173,7 +172,7 @@ impl<F: FileSystem + Sync, D: AsyncDrive> Server<F, D> {
             None
         };
         let valid = SetattrValid::from_bits_truncate(setattr_in.valid);
-        let st: libc::stat64 = setattr_in.into();
+        let st: stat64 = setattr_in.into();
         let result = self
             .fs
             .setattr(ctx.context(), ctx.nodeid(), st, handle, valid);
@@ -282,7 +281,7 @@ impl<F: FileSystem + Sync, D: AsyncDrive> Server<F, D> {
     }
 
     pub(super) fn rename<S: BitmapSlice>(&self, mut ctx: SrvContext<'_, F, D, S>) -> Result<usize> {
-        let RenameIn { newdir } = ctx.r.read_obj().map_err(Error::DecodeMessage)?;
+        let RenameIn { newdir, .. } = ctx.r.read_obj().map_err(Error::DecodeMessage)?;
 
         self.do_rename(ctx, size_of::<RenameIn>(), newdir, 0)
     }
@@ -293,9 +292,13 @@ impl<F: FileSystem + Sync, D: AsyncDrive> Server<F, D> {
     ) -> Result<usize> {
         let Rename2In { newdir, flags, .. } = ctx.r.read_obj().map_err(Error::DecodeMessage)?;
 
+        #[cfg(target_os = "linux")]
         let flags =
             flags & (libc::RENAME_EXCHANGE | libc::RENAME_NOREPLACE | libc::RENAME_WHITEOUT) as u32;
 
+        #[cfg(target_os = "macos")]
+        let flags = flags & (libc::RENAME_EXCL | libc::RENAME_SWAP) as u32;
+
         self.do_rename(ctx, size_of::<Rename2In>(), newdir, flags)
     }
 
@@ -635,10 +638,16 @@ impl<F: FileSystem + Sync, D: AsyncDrive> Server<F, D> {
                     major, minor, capable, enabled
                 );
 
+                let readahead = if cfg!(target_os = "macos") {
+                    0
+                } else {
+                    max_readahead
+                };
+
                 let mut out = InitOut {
                     major: KERNEL_VERSION,
                     minor: KERNEL_MINOR_VERSION,
-                    max_readahead,
+                    max_readahead: readahead,
                     flags: enabled.bits(),
                     max_background: ::std::u16::MAX,
                     congestion_threshold: (::std::u16::MAX / 4) * 3,
@@ -918,9 +927,11 @@ impl<F: FileSystem + Sync, D: AsyncDrive> Server<F, D> {
         }
     }
 
-    pub(super) fn destroy(&self) {
-        // No reply to this function.
+    pub(super) fn destroy<S: BitmapSlice>(&self, mut ctx: SrvContext<'_, F, D, S>) {
         self.fs.destroy();
+        if let Err(e) = ctx.reply_ok(None::<u8>, None) {
+            warn!("fuse channel reply destroy failed {:?}", e);
+        }
     }
 
     pub(super) fn ioctl<S: BitmapSlice>(&self, mut ctx: SrvContext<'_, F, D, S>) -> Result<usize> {
@@ -1222,10 +1233,7 @@ impl<'a, F: FileSystem, D: AsyncDrive, S: BitmapSlice> SrvContext<'a, F, D, S> {
         self.do_reply_error(err, true)
     }
 
-    fn handle_attr_result(
-        &mut self,
-        result: io::Result<(libc::stat64, Duration)>,
-    ) -> Result<usize> {
+    fn handle_attr_result(&mut self, result: io::Result<(stat64, Duration)>) -> Result<usize> {
         match result {
             Ok((st, timeout)) => {
                 let out = AttrOut {
